@@ -478,9 +478,9 @@ class Reaction(object):
         >>> from chempy.units import to_unitless, default_units as u
         >>> to_unitless(r3.param, u.hour**-1)
         3600.0
-        >>> r4 = Reaction.from_string("A -> B; 'k'", 'A B')
-        >>> r4.param.unique_keys
-        ('k',)
+        >>> r4 = Reaction.from_string("A -> 2 B; 'k'", 'A B')
+        >>> r4.rate(dict(A=3, B=5, k=7)) == {'A': -3*7, 'B': 2*3*7}
+        True
         >>> r5 = Reaction.from_string("A -> B; 1/molar/second", 'A B')
         Traceback (most recent call last):
             ...
@@ -1040,6 +1040,7 @@ class Equilibrium(Reaction):
             flip = True
         else:
             flip = False
+        other = int(other)  # convert SymPy "Integer" to Pyton "int"
         reac = dict(other*ArithmeticDict(int, self.reac))
         prod = dict(other*ArithmeticDict(int, self.prod))
         inact_reac = dict(other*ArithmeticDict(int, self.inact_reac))
@@ -1242,7 +1243,7 @@ def balance_stoichiometry(reactants, products, substances=None,
                         r, p, substances=substances, substance_factory=substance_factory,
                         parametric_symbols=parametric_symbols, underdetermined=underdetermined,
                         allow_duplicates=False)
-                except Exception:
+                except ValueError:
                     continue
                 else:
                     return result
@@ -1283,12 +1284,23 @@ def balance_stoichiometry(reactants, products, substances=None,
             if substances[rk].composition.get(ck, 0) != 0:
                 break
         else:
-            raise ValueError("Component '%s' not among reactants" % ck)
+            any_pos = any(substances[pk].composition.get(ck, 0) > 0 for pk in products)
+            any_neg = any(substances[pk].composition.get(ck, 0) < 0 for pk in products)
+            if any_pos and any_neg:
+                pass  # negative and positive parts among products, no worries
+            else:
+                raise ValueError("Component '%s' not among reactants" % ck)
+
         for pk in products:
             if substances[pk].composition.get(ck, 0) != 0:
                 break
         else:
-            raise ValueError("Component '%s' not among products" % ck)
+            any_pos = any(substances[pk].composition.get(ck, 0) > 0 for pk in reactants)
+            any_neg = any(substances[pk].composition.get(ck, 0) < 0 for pk in reactants)
+            if any_pos and any_neg:
+                pass  # negative and positive parts among reactants, no worries
+            else:
+                raise ValueError("Component '%s' not among products" % ck)
 
     A = MutableDenseMatrix([[_get(ck, sk) for sk in subst_keys] for ck in cks])
     symbs = list(reversed([next(parametric_symbols) for _ in range(len(subst_keys))]))
@@ -1330,7 +1342,8 @@ def balance_stoichiometry(reactants, products, substances=None,
                     cd = gcd(cd, term.args[0])
         if cd != 1:
             sol = sol.func(*[arg.subs(symb, symb/cd) for arg in sol.args])
-    if underdetermined is 1:
+    integer_one = 1  # need 'is' check, SyntaxWarning when checking against literal
+    if underdetermined is integer_one:
         from ._release import __version__
         if int(__version__.split('.')[1]) > 6:
             warnings.warn(  # deprecated because comparison with ``1`` problematic (True==1)
