@@ -83,27 +83,25 @@ def sulfuric_acid_density(w, T=None, T0=None, units=None, warn=True):
     return np.sum((t_arr*w_arr)*_data)*kg/m3  # Equation (2) in reference
 
 
-# generated at doi2bib.org:
-bibtex = """
-@article{Myhre1998,
-  doi = {10.1021/je980013g},
-  url = {http://dx.doi.org/10.1021/je980013g},
-  year  = {1998},
-  month = {jul},
-  publisher = {American Chemical Society ({ACS})},
-  volume = {43},
-  number = {4},
-  pages = {617--622},
-  author = {Cathrine E. L. Myhre and Claus J. Nielsen and Ole W. Saastad},
-  title = {Density and Surface Tension of Aqueous H2{SO}4 at Low Temperature},
-  journal = {Journal of Chemical {\&} Engineering Data}
+# bibtex format (generated at doi2bib.org):
+reference = {
+    'doi': '10.1021/je980013g',
+    'url': 'http://dx.doi.org/10.1021/je980013g',
+    'year ': 1998,
+    'month': 'jul',
+    'publisher': 'American Chemical Society ({ACS})',
+    'volume': 43,
+    'number': 4,
+    'pages': (617, 622),
+    'author': 'Cathrine E. L. Myhre and Claus J. Nielsen and Ole W. Saastad',
+    'title': 'Density and Surface Tension of Aqueous H2{SO}4 at Low Temperature',
+    'journal': r'Journal of Chemical {\&} Engineering Data'
 }
-"""
 
 
 def density_from_concentration(conc, T=None, molar_mass=None,
                                rho_cb=sulfuric_acid_density,
-                               units=None, atol=None, maxiter=50, **kwargs):
+                               units=None, atol=None, maxiter=10, warn=False, **kwargs):
     """ Calculates the density of a solution from its concentration
 
     Given a function which calculates the density of a solution from the mass
@@ -112,25 +110,25 @@ def density_from_concentration(conc, T=None, molar_mass=None,
 
     Parameters
     ----------
-    conc: float (optionally with units)
-        concentration (mol / m³)
-    T: float (optionally with units)
-        passed to ``rho_cb``
-    molar_mass: float (optionally with units)
-        Molar mass of solute
-    rho_cb: callback
-        callback with signature f(w, T, units=None) -> rho
-        (default: :func:`sulfuric_acid_density`)
-    units: object (optional)
-        object with attributes: meter, kilogram, mol
-    atol: float (optionally with units)
-        convergence criterion for fixed-point iteration
-        (default: 1e-3 kg/m³)
-    maxiter: int
-        maximum number of iterations (when exceeded a NoConvergence excpetion
-        is raised)
-    \*\*kwargs:
-        keyword arguments passed onto ``rho_cb``
+    conc : float (optionally with units)
+        Concentration (mol / m³).
+    T : float (optionally with units)
+        Passed to ``rho_cb``.
+    molar_mass : float (optionally with units)
+        Molar mass of solute.
+    rho_cb : callback
+        Callback with signature f(w, T, units=None) -> rho
+        (default: :func:`sulfuric_acid_density`).
+    units : object (optional)
+        Object with attributes: meter, kilogram, mol.
+    atol : float (optionally with units)
+        Convergence criterion for fixed-point iteration
+        (default: 1e-3 kg/m³).
+    maxiter : int
+        Maximum number of iterations (when exceeded a NoConvergence excpetion
+        is raised).
+    \\*\\*kwargs:
+        Keyword arguments passed onto ``rho_cb``.
 
     Returns
     -------
@@ -161,13 +159,17 @@ def density_from_concentration(conc, T=None, molar_mass=None,
     if molar_mass is None:
         molar_mass = (1.00794*2 + 32.066 + 4*15.9994)*1e-3 * kg / mol
 
+    if units is not None:
+        conc = conc.rescale(mol/m**3)
+        molar_mass = molar_mass.rescale(kg/mol)
+
     rho = 1100 * kg_per_m3
     delta_rho = float('inf') * kg_per_m3
 
     iter_idx = 0
     while atol < abs(delta_rho):
         # fixed point iteration
-        new_rho = rho_cb(conc*molar_mass/rho, T, units=units, **kwargs)
+        new_rho = rho_cb(conc*molar_mass/rho, T, units=units, warn=warn, **kwargs)
         delta_rho = new_rho - rho
         rho = new_rho
         iter_idx += 1
