@@ -3,6 +3,8 @@ import warnings
 from chempy.units import allclose
 
 from ..water_permittivity_bradley_pitzer_1979 import water_permittivity
+from chempy.util.testing import requires
+from chempy.units import linspace, units_library, default_units as u
 
 
 def test_water_permittivity():
@@ -19,14 +21,12 @@ def test_water_permittivity():
         raise
     warnings.resetwarnings()
 
-    try:
-        import quantities as pq
-        import numpy as np
-        assert allclose(water_permittivity(
-            298.15*pq.K, 1*pq.bar,
-            units=pq), 78.38436874203077)
-        assert allclose(water_permittivity(
-            np.linspace(297.5, 298.65)*pq.K, 1*pq.bar,
-            units=pq), 78, rtol=1e-2, atol=1e-2)
-    except ImportError:
-        pass
+
+@requires(units_library)
+def test_water_permittivity__units():
+    assert allclose(water_permittivity(
+        298.15*u.K, 1*u.bar,
+        units=u), 78.38436874203077)
+    assert allclose(water_permittivity(
+        linspace(297.5, 298.65)*u.K, 1*u.bar,
+        units=u), 78, rtol=1e-2, atol=1e-2)
