@@ -2,10 +2,7 @@
 
 from __future__ import absolute_import, division, print_function
 
-
-class AttributeDict(object):
-    def __init__(self, d):
-        self.__dict__.update(d)
+from .util.pyutil import AttributeContainer
 
 
 def get_constant_symbols(Symbol=None):
@@ -19,4 +16,4 @@ def get_constant_symbols(Symbol=None):
         ('pi', 'pi'),
         ('molar_gas_constant', 'R'),
     ]
-    return AttributeDict({k: Symbol(v) for k, v in consts})
+    return AttributeContainer(**{k: Symbol(v) for k, v in consts})
