@@ -5,6 +5,24 @@ from collections import defaultdict
 from itertools import chain
 
 
+def _imul(d1, d2):
+    if hasattr(d2, 'keys'):
+        for k in set(chain(d1.keys(), d2.keys())):
+            d1[k] = d1[k]*d2[k]
+    else:
+        for k in d1:
+            d1[k] *= d2
+
+
+def _itruediv(d1, d2):
+    if hasattr(d2, 'keys'):
+        for k in set(chain(d1.keys(), d2.keys())):
+            d1[k] = d1[k]/d2[k]
+    else:
+        for k in d1:
+            d1[k] /= d2
+
+
 class ArithmeticDict(defaultdict):
     """ A dictionary which supports arithmetics
 
@@ -12,7 +30,7 @@ class ArithmeticDict(defaultdict):
     multiplication and division. If other term/factor has a :meth:`keys` method
     the arithmetics are performed on a key per key basis. If :meth:`keys` is
     missing, the operation is broadcasted onto all values.
-    Nonexisting keys are interpreted to signal a zero
+    Nonexisting keys are interpreted to signal a zero.
 
     Notes
     -----
@@ -75,12 +93,7 @@ class ArithmeticDict(defaultdict):
         return -1*self + other
 
     def __imul__(self, other):
-        if hasattr(other, 'keys'):
-            for k in set(chain(self.keys(), other.keys())):
-                self[k] = self[k]*other[k]
-        else:
-            for k in self:
-                self[k] *= other
+        _imul(self, other)
         return self
 
     def __mul__(self, other):
@@ -92,12 +105,7 @@ class ArithmeticDict(defaultdict):
         return self * other
 
     def __itruediv__(self, other):
-        if hasattr(other, 'keys'):
-            for k in set(chain(self.keys(), other.keys())):
-                self[k] = self[k]/other[k]
-        else:
-            for k in self:
-                self[k] /= other
+        _itruediv(self, other)
         return self
 
     def __truediv__(self, other):
@@ -110,37 +118,62 @@ class ArithmeticDict(defaultdict):
         return self.__class__(self.default_factory,
                               {k: other/v for k, v in self.items()})
 
-    __div__ = __truediv__  # Py2 compability
-    __idiv__ = __itruediv__  # Py2 compability
-    __rdiv__ = __rtruediv__  # Py2 compability
+    def __ifloordiv__(self, other):
+        if hasattr(other, 'keys'):
+            for k in set(chain(self.keys(), other.keys())):
+                self[k] = self[k]//other[k]
+        else:
+            for k in self:
+                self[k] //= other
+        return self
+
+    def __floordiv__(self, other):
+        a = self.copy()
+        a //= other
+        return a
+
+    def __rfloordiv__(self, other):
+        """ other // self """
+        return self.__class__(self.default_factory,
+                              {k: other//v for k, v in self.items()})
+
+    __div__ = __truediv__  # Py2 compatibility (or: import division from __future__)
+    __idiv__ = __itruediv__  # Py2 compatibility
+    __rdiv__ = __rtruediv__  # Py2 compatibility
 
     def __repr__(self):
         return "{}({}, {})".format(self.__class__.__name__,
                                    repr(self.default_factory),
                                    dict(self))
 
-    def __eq__(self, other):
+    def _element_eq(self, a, b):
+        return a == b
+
+    def _discrepancy(self, other, cb):
         default = self.default_factory()
+        _self = self.copy()  # getitem is not idempotent on defaultdict
+        _other = other.copy()
         try:
-            for k, v in self.items():
-                if v == default:
-                    continue
-                if v != other[k]:
+            for k in set(chain(_self.keys(), _other.keys())):
+                if not cb(_self[k], _other.get(k, default)):
                     return False
-            for k, v in other.items():
-                if v == default:
-                    continue
-                if k in self:
-                    continue
-                return False
             return True
         except TypeError:
             return False
 
-    def __hash__(self):
-        default = self.default_factory()
-        l = [self.default_factory]
-        for k, v in self.items():
-            if v != default:
-                l.append((k, v))
-        return hash(tuple(l))
+    def __eq__(self, other):
+        return self._discrepancy(other, self._element_eq)
+
+    def isclose(self, other, rtol=1e-12, atol=None):
+        def _isclose(a, b):
+            lim = abs(rtol*b)
+            if atol is not None:
+                lim += atol
+            return abs((a-b)) <= lim
+        return self._discrepancy(other, _isclose)
+
+    def all_non_negative(self):
+        for v in self.values():
+            if v < v*0:
+                return False
+        return True
