@@ -10,6 +10,8 @@ import shutil
 import subprocess
 import tempfile
 
+from ..printing import latex
+from ..kinetics.rates import RadiolyticBase
 from ..units import to_unitless, get_derived_unit
 
 tex_templates = {
@@ -72,11 +74,11 @@ def render_tex_to_pdf(contents, texfname, pdffname, output_dir, save):
 
     Parameters
     ----------
-    contents: str
-    texfname: path
-    pdffname: path
-    output_dir: path
-    save: path or bool or str(bool)
+    contents : str
+    texfname : path
+    pdffname : path
+    output_dir : path
+    save : path or bool or str(bool)
 
     """
     created_tempdir = False
@@ -112,37 +114,43 @@ def render_tex_to_pdf(contents, texfname, pdffname, output_dir, save):
                     shutil.rmtree(output_dir)
             else:
                 # interpret path to copy pdf to.
-                shutil.copy(pdfpath, save)
+                if not os.path.samefile(pdfpath, save):
+                    shutil.copy(pdfpath, save)
 
 
 def rsys2tablines(rsys, rref0=1, coldelim=' & ',
                   tex=True, ref_fmt=None,
-                  unit_registry=None, unit_fmt='{}', k_fmt='{0:.4g}'):
+                  unit_registry=None, unit_fmt='{}', k_fmt='%.4g'):
     """
     Generates a table representation of a ReactionSystem.
 
     Parameters
     ----------
-    rsys: ReactionSystem
-    rref0: integer
+    rsys : ReactionSystem
+    rref0 : integer
         default start of index counter (default: 1)
-    coldelim: string
+    coldelim : string
         column delimiter (default: ' & ')
-    tex: bool
+    tex : bool
         use latex formated output (default: True)
-    ref_fmt: string or callable
+    ref_fmt : string or callable
         format string of ``ref`` attribute of reactions
-    unit_registry: unit registry
+    unit_registry : unit registry
         optional (default: None)
     """
     if ref_fmt is None:
+        def _doi(s):
+            return r'\texttt{\href{http://dx.doi.org/'+s+'}{doi:'+s+'}}'
+
         def ref_fmt(s):
             if s is None:
                 return 'None'
-            if tex and s.startswith('doi:'):
-                return r'\texttt{\href{http://dx.doi.org/'+s[4:]+'}{'+s+'}}'
-            else:
-                return s
+            if tex:
+                if isinstance(s, dict):
+                    return _doi(s['doi'])
+                if s.startswith('doi:'):
+                    return _doi(s[4:])
+            return s
 
     def _wrap(s):
         if tex:
@@ -153,31 +161,42 @@ def rsys2tablines(rsys, rref0=1, coldelim=' & ',
     lines = []
     for ri, rxn in enumerate(rsys.rxns):
         rxn_ref = rxn.ref
-        if unit_registry is not None:
-            kunit = (get_derived_unit(unit_registry,
-                                      'concentration')**(1-rxn.order()) /
-                     get_derived_unit(unit_registry, 'time'))
-            try:
-                k = k_fmt.format(to_unitless(rxn.param, kunit))
-                k_unit_str = (kunit.dimensionality.latex if tex
+        if isinstance(rxn.param, RadiolyticBase):
+            if unit_registry is not None:
+                kunit = get_derived_unit(unit_registry, 'radiolytic_yield')
+                k = k_fmt % to_unitless(rxn.param.args[0], kunit)
+                k_unit_str = (kunit.dimensionality.latex.strip('$') if tex
                               else kunit.dimensionality)
-            except:
-                k = rxn.param.equation_as_string(k_fmt, tex)
-                k_unit_str = '-'
         else:
-            k_unit_str = '-'
-            k = k_fmt.format(rxn.param)
-        r_str, ir_str, arrow_str, p_str, ip_str = rxn._get_str_parts(
-            'latex_name' if tex else 'name',
-            'latex_arrow' if tex else 'str_arrow',
-            rsys.substances)
+            if unit_registry is not None:
+                kunit = (get_derived_unit(unit_registry,
+                                          'concentration')**(1-rxn.order()) /
+                         get_derived_unit(unit_registry, 'time'))
+                try:
+                    k = k_fmt % to_unitless(rxn.param, kunit)
+                    k_unit_str = (kunit.dimensionality.latex.strip('$') if tex
+                                  else kunit.dimensionality)
+                except Exception:
+                    k, k_unit_str = rxn.param.equation_as_string(k_fmt, tex)
+            else:
+                k_unit_str = '-'
+                if isinstance(k_fmt, str):
+                    k = k_fmt % rxn.param
+                else:
+                    k = k_fmt(rxn.param)
+        latex_kw = dict(with_param=False, with_name=False)
+        if tex:
+            latex_kw['substances'] = rsys.substances
+            latex_kw['Reaction_around_arrow'] = ('}}' + coldelim + '\\ensuremath{{',
+                                                 '}}' + coldelim + '\\ensuremath{{')
+        else:
+            latex_kw['Reaction_around_arrow'] = (coldelim,)*2
+            latex_kw['Reaction_arrow'] = '->'
         lines.append(coldelim.join([
             str(rref0+ri),
-            _wrap(r_str + ir_str),
-            _wrap(arrow_str),
-            _wrap(p_str + ip_str),
+            ('\\ensuremath{%s}' if tex else '%s') % latex(rxn, **latex_kw),
             _wrap(k),
-            unit_fmt.format(k_unit_str),
+            unit_fmt.format(_wrap(k_unit_str)),
             ref_fmt(rxn_ref) if callable(ref_fmt) else ref_fmt.format(rxn_ref)
         ]))
 
@@ -194,16 +213,17 @@ def rsys2table(rsys, table_template=None, table_template_dict=None,
     (add \usepackage{booktabs} to preamble).
 
     Parameters
-    ==========
-    rsys: ReactionSystem
-    table_template: string
-    table_tempalte_dict: dict used to render table_template (excl. "body")
-    param_name: str
+    ----------
+    rsys : ReactionSystem
+    table_template : string
+    table_tempalte_dict : dict used to render table_template (excl. "body")
+    param_name : str
         Column header for parameter column
-    longtable: bool
+    longtable : bool
         use longtable in defaults. (default: False)
-    **kwargs:
+    **kwargs :
         passed onto rsys2tablines
+
     """
     siunitx = kwargs.pop('siunitx', False)
     line_term = r' \\'
@@ -229,8 +249,11 @@ def rsys2table(rsys, table_template=None, table_template_dict=None,
 
     if 'body' in table_template_dict:
         raise KeyError("There is already a 'body' key in table_template_dict")
+    if 'k_fmt' not in kwargs:
+        kwargs['k_fmt'] = r'\num{%.4g}' if siunitx else '%.4g'
     table_template_dict['body'] = (line_term + '\n').join(rsys2tablines(
-        rsys, k_fmt=r'\num{{{0:.4g}}}' if siunitx else '{0:.4g}', **kwargs)) + line_term
+        rsys, **kwargs)
+    ) + line_term
 
     if table_template is None:
         if table_template_dict['table_env'] == 'longtable':
@@ -249,35 +272,34 @@ def rsys2pdf_table(rsys, output_dir=None, doc_template=None,
     e.g. a pdf using e.g. pdflatex.
 
     Parameters
-    ==========
-    rsys: ReactionSystem
-    output_dir: path to output directory
+    ----------
+    rsys : ReactionSystem
+    output_dir : path to output directory
         (default: system's temporary folder)
-    doc_template: string
+    doc_template : string
         LaTeX boiler plate temlpate including preamble,
         document environment etc.
-    doc_template_dict: dict (string -> string)
+    doc_template_dict : dict (string -> string)
         dict used to render temlpate (excl. 'table')
-    longtable: bool
+    longtable : bool
         use longtable in defaults. (default: False)
-    **kwargs:
+    **kwargs :
         passed on to `rsys2table`
     """
     if doc_template is None:
         doc_template = tex_templates['document']['default']
+    lscape = ['pdflscape' if landscape == 'pdf' else 'lscape'] if landscape else []
     _pkgs = [
-        'booktabs', 'amsmath', ('pdftex,colorlinks,unicode=True',
-                                'hyperref')] + (
-                                    ['lscape'] if landscape else [])
+        'booktabs', 'amsmath', ('pdftex,colorlinks,unicode=True', 'hyperref')
+    ] + lscape
     if kwargs.get('longtable', False):
         _pkgs += ['longtable']
     if kwargs.get('siunitx', False):
         _pkgs += ['siunitx']
     _envs = ['tiny'] + (['landscape'] if landscape else [])
     defaults = {
-        'usepkg': '\n'.join([(r'\usepackage' + ('[%s]' if isinstance(pkg, tuple)
-                                                else '') + '{%s}') % pkg for
-                             pkg in _pkgs]),
+        'usepkg': '\n'.join([(r'\usepackage' + (
+            '[%s]' if isinstance(pkg, tuple) else '') + '{%s}') % pkg for pkg in _pkgs]),
         'begins': '\n'.join([r'\begin{%s}' % env for env in _envs]),
         'ends': '\n'.join([r'\end{%s}' % env for env in _envs[::-1]])
     }
@@ -295,6 +317,10 @@ def rsys2pdf_table(rsys, output_dir=None, doc_template=None,
 
     contents = doc_template % doc_template_dict
 
-    texfname = 'output.tex'
-    pdffname = 'output.pdf'
+    if isinstance(save, str) and save.endswith('.pdf'):
+        texfname = save.rstrip('.pdf') + '.tex'
+        pdffname = save
+    else:
+        texfname = 'output.tex'
+        pdffname = 'output.pdf'
     return render_tex_to_pdf(contents, texfname, pdffname, output_dir, save)
