@@ -118,6 +118,29 @@ def test_ArithmeticDict_div():
     assert d3['c'] == 0
 
 
+def test_ArithmeticDict_floordiv():
+    d1 = ArithmeticDict(int, [('a', 6), ('b', 9)])
+
+    d2 = d1//2
+    assert d2['a'] == 3
+    assert d2['b'] == 4
+
+    d2 = d1.copy() // 5
+    assert d2['a'] == 1
+    assert d2['b'] == 1
+
+    d2 = 55//d1
+    assert d2['a'] == 9
+    assert d2['b'] == 6
+    assert d2['c'] == 0
+
+    d1['c'] = 1
+    d3 = (6*d2 + 1)//d1
+    assert d3['a'] == 9
+    assert d3['b'] == 4
+    assert d3['c'] == 1
+
+
 def test_ArithmeticDict_idiv():
     d1 = ArithmeticDict(int, [('a', 6), ('b', 9)])
     d1 /= 3
@@ -133,3 +156,35 @@ def test_ArithmeticDict_div_float():
     t = d/3.0
     assert t['a'] == 2.0
     assert t['b'] == 3.0
+
+
+def test_ArithmeticDict_isclose():
+    d1 = ArithmeticDict(float)
+    d2 = ArithmeticDict(float)
+    assert d1.isclose(d2)
+    d1['a'] = 2
+    assert not d1.isclose(d2)
+    d2['a'] = 2+1e-15
+    assert d1.isclose(d2)
+    d2['b'] = 1e-15
+    assert not d1.isclose(d2)
+    assert d1.isclose(d2, atol=1e-14)
+
+
+def test_ArithmeticDict_all_non_negative():
+    d1 = ArithmeticDict(float)
+    assert d1.all_non_negative()
+    d1['a'] = .1
+    assert d1.all_non_negative()
+    d1['b'] = 0
+    assert d1.all_non_negative()
+    d1['b'] -= 1e-15
+    assert not d1.all_non_negative()
+
+
+def test_ArithmeticDict_eq():
+    d1 = ArithmeticDict(int, a=1, b=0)
+    d2 = ArithmeticDict(int, a=1, b=1)
+    d3 = ArithmeticDict(int, a=1)
+    assert not d1 == d2
+    assert d1 == d3
